#
# spec file for package SHERPA-MC
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname lib%{name}0
%define _lto_cflags %{nil}

Name:           SHERPA-MC
Version:        2.2.15
Release:        1.1
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
License:        GPL-2.0-or-later AND GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://sherpa-team.gitlab.io/
#Git-Clone:     https://gitlab.com/sherpa-team/sherpa.git
Source:         https://www.hepforge.org/downloads/sherpa/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM SHERPA-MC-no-return-in-non-void-function.patch badshah400@gmail.com -- Fix a non-void (bool) function that was not returning any data to return "true"
Patch0:         SHERPA-MC-no-return-in-non-void-function.patch
# PATCH-FIX-UPSTREAM SHERPA-MC-ignore-distutils-deprecation-warning.patch badshah400@gmail.com -- Disable deprecation warning when importing distutils from python3.10, so that autotools can still work
Patch1:         SHERPA-MC-ignore-distutils-deprecation-warning.patch
# PATCH-FIX-UPSTREAM SHERPA-MC-swig-noruntime.patch badshah400@gmail.com -- Drop `-noruntime` from swig command line
Patch2:         SHERPA-MC-swig-noruntime.patch
BuildRequires:  HepMC-devel >= 3.0
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
BuildRequires:  fastjet-contrib-devel
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 6
BuildRequires:  gcc-fortran >= 6
BuildRequires:  libboost_headers-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pythia-devel
BuildRequires:  python3-devel
BuildRequires:  sqlite3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  pkgconfig(zlib)

%description
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

Sherpa simulations can be achieved for the following types of
collisions:
 - For lepton–lepton collisions, as explored by the CERN LEP
   experiments,
 - for lepton–photon collisions,
 - for photon–photon collisions with both photons either resolved or
   unresolved,
 - for deep-inelastic lepton-hadron scattering, as investigated by
   the HERA experiments at DESY, and,
 - in particular, for hadronic interactions as studied at the
   Fermilab Tevatron or the CERN LHC.

%package -n %{soname}
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
Group:          System/Libraries
Requires:       libSHERPA-MC-config
Obsoletes:      libSHERPA-MC < %{version}-%{release}
Provides:       libSHERPA-MC = %{version}-%{release}

%description -n %{soname}
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the shared libraries for Sherpa.

%package -n %{soname}-config
Summary:        Dynamic linker configuration for the SHERPA-MC libraries
Group:          System/Base
Provides:       libSHERPA-MC-config = %{version}
Obsoletes:      libSHERPA-MC-config < %{version}
BuildArch:      noarch

%description -n %{soname}-config
Contains the ld.so.conf.d file for the SHERPA-MC libraries.

%package devel
Summary:        MC event generator for Simulation of High-Energy Reactions of PArticles
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description devel
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the source and header files for development with
Sherpa.

%package -n python3-%{name}
Summary:        Python extensions for SHERPA-MC
Group:          Development/Languages/Python
Provides:       python-%{name} = %{version}
Obsoletes:      python-%{name} < %{version}

%description -n python3-%{name}
Sherpa is a Monte Carlo event generator for the Simulation of
High-Energy Reactions of PArticles in lepton-lepton, lepton-photon,
photon-photon, lepton-hadron and hadron-hadron collisions. It provides
complete hadronic final states in simulations of high-energy particle
collisions. The produced events may be passed into detector
simulations used by the various experiments. The entire code has been
written in C++.

This package provides the python extensions for Sherpa.

%prep
%autosetup -p1

# REMOVE HASHBANGS FROM FILES NOT TO BE INSTALLED TO EXEC PATH
sed -E -i "1{s|#!/bin/env python2||}"     MODEL/UFO/test.py
sed -E -i "1{s|#!/usr/bin/python2||}"     Examples/API/Events/test.py.in
sed -E -i "1{s|#!/usr/bin/python2||}"     Examples/API/MPIEvents/test.py.in
sed -E -i "1{s|#!/usr/bin/env python2||}" Examples/API/ME2-Python/test.py.in

%build
export PYTHON=python3
export PYTHON_VERSION=%{py3_ver}
autoreconf -fvi
%configure \
  --docdir=%{_docdir}/%{name}  \
  --enable-ufo                 \
  --enable-pyext               \
  --enable-analysis            \
  --enable-multithread         \
  --enable-gzip                \
  --disable-hepmc3root         \
  --enable-hepmc3=%{_prefix}   \
  --enable-fastjet=%{_prefix}  \
  --enable-lhapdf=%{_prefix}   \
  --enable-rivet=%{_prefix}    \
  --enable-pythia=%{_prefix}

%make_build

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{soname}.conf

find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_datadir}/%{name}/
%fdupes %{buildroot}%{python3_sitelib}/

%post -n %{soname} -p /sbin/ldconfig

%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so.*

%files -n %{soname}-config
%config %{_sysconfdir}/ld.so.conf.d/%{soname}.conf

%files devel
%license COPYING
%doc ChangeLog README
%{_bindir}/get_bibtex
%{_bindir}/Combine_Analysis
%{_bindir}/Sherpa
%{_bindir}/Sherpa-config
%{_bindir}/init_nlo.sh
%{_bindir}/make2scons
%{_bindir}/plot_graphs.sh
%{_bindir}/plot_stats.sh
%{_bindir}/sconsloops
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/*.html
%{_docdir}/%{name}/*.jpg
%{_libdir}/%{name}/*.so
%{_includedir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man1/Sherpa.*.gz
%{_infodir}/Sherpa.*.gz

%files -n python3-%{name}
%{_bindir}/Sherpa-generate-model
%{python3_sitelib}/Sherpa.py*
%{python3_sitelib}/ufo_interface/
%{python3_sitelib}/_Sherpa.*
%{python3_sitelib}/__pycache__/

%changelog
* Sun Mar 31 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.15:
  * Fix for fixed-order NLO results (enabled using QCD_NLO_Mode:
    Fixed_Order).
- Changes from version 2.2.14:
  * Fix: Reinstate clustering in OneHEvent to fix physics issue.
- Changes from version 2.2.13:
  * New:
  - Expand pilot technology to scale setting (using the new
    PILOT scale setter) and to loop generators (using the
    process Pilot_Loop_Generator setting) !564 !461
  - Allow to not read in partonic decay data, e.g. if one wants
    to select a single B or D decay !537
  * Technical/performance improvements:
  - Make sure that HepMC3 output only correctly reports two beam
    particles !572
  - Use consistent order of weight names in HepMC3 output as in
    HepMC2 output !459
  - Resurrect HepMC3_Short output format !512
  - Adapt pilot run strategy to be compatible with (adapted)
    external RNG !497
  - Fix memory leak in fusing hooks !403
  * Fixes of runtime issues:
  - Fix for missing tau spin correlations !574
  - Fix crash when using a neutron-neutron beam setup !553
  - Fix PDF book-keeping issues in the event output when using
    the pilot run !508 !532
  - Fix potential unit (e.g. MeV vs. GeV) inconsistency for
    correlated subevents !512
  - Throw exception instead of silently reweighting AlphaS input
    scales where it is not appropriate !455
  - Fix crash when using weighted event generation without any
    on-the-fly variations !473
  - Reset non-perturbative event phases after Retry_Event,
    removing the occurence of spurious tau decays !526
- Add SHERPA-MC-swig-noruntime.patch: Drop `-noruntime` from swig
  command line as it has been deprecated since version 4.0 and
  dropped from 4.2.x.
* Thu Jun 30 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add Git-Clone URL
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add SHERPA-MC-ignore-distutils-deprecation-warning.patch:
  Disable deprecation warning when importing distutils from
  python3.10, so that autotools checks can still work.
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.12:
  * Significant speed-up of (partially) unweighted event
    generation with on-the-fly variations enabled, e.g. for many
    PDF variations or implicitly when EWvirt associated
    contributions are evaluated !410
  * New option to perform (significantly faster) uncorrelated
    mc@nlo matching after unweighting, enabled by flag
    NLO_CSS_PSMODE: 2 !410
  * Further performance improvements !410
  * New MCFM interface (bd3e25ad, TODO: @shoeche to provide more
    info) !409
  * CSS improvements (efcffda4, TODO: @shoeche to provide more
    info) !410
  * New output options steered through BATCH_MODE !410 (see Manual
    for additional information):
  - 8 prints the current process name,
  - 16 prints the time elapsed/left in unformatted seconds
  * Runtime issues: Fix compatibility issue when using binary
    relocation after installation !453
  * Improve compatibility with autoconf 2.70 or later (in
    particular when building process libraries without scons) !396
  * Fix MadLoop 5 interface add-on installation
  * Fix Recola interface add-on compilation !410
* Mon Feb 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.11:
  * Improvements in ME+PS merging for unordered scale
    configurations !381
  * New NLO_SUBTRACTION_SCHEME option for improved behavior of the
    parton shower in processes with large higher-order
    contributions from t-channel gluon exchange !382
  * Additional power corrections to better match soft limit !394
  * Implement csin2_thetaW for SMEFTsim !319
  * Exponentiation version of EWvirt corrections !348
  * Phase space enhancing with function for unweighted event
    generation (Enhance_Function) !357 !379
  * Rivet interface improvements: zipped YODA files (!374) and
    split pos/neg weights (!376)
  * Runtime issues
  - Bugfix in Comix for models with vertices with negative
    coupling orders !327
  - Bugfixes for crashes with new SPECIAL_TAU_SPIN_CORRELATIONS
    option !335 !362
  - Bugfix for crash with spin correlations in ttll setups !388
  - Bugfixes for non-standard KFACTOR treatments !352
  * Compilation issues
  - Fix build problem with very new glibc !328
  - Updated swig requirement for python interface to 2.0.12 !342
  - Improvements in HepMC3 linking !380
  - MCFM interface fixes !389
- Drop SHERPA-MC-build-with-recent-glibc.patch: incorporated
  upstream.
- Add BuildRequires: libtool needed for building swig-based
  bindings for updated version.
* Wed Nov 25 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add SHERPA-MC-build-with-recent-glibc.patch to fix builds
  against recent glibc; patch taken from upstream git.
* Wed Jun  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop post(un) install-info scripts for devel pkg, these are
  handled by rpm file triggers; also drop the appropriate
  dependencies.
* Sat May 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.10:
  * Further improvements for Rivet3 and HepMC3 compatibility
    [!321, !314].
  * Bugfix for crashes with new heavy-flavour shower evolution
    schemes [!313].
  * Bugfix for crash in ReweightWithoutSubevents [!318].
  * Bugfix for documentation signal blob with pre-NLO+PS
    kinematics [!320].
  * Bugfix for crash in setups with neutron beams [!312].
  * More robust discovery of HZTool and HepMC3 ROOT IO libraries
    [!317, !322, !323].
- Changes from version 2.2.9: See
  https://gitlab.com/sherpa-team/sherpa/-/tags/v2.2.9.
- Build with Rivet support (BuildRequires: Rivet-devel).
- Fix some incorrect Provides and Obsoletes in subpackages.
- Execute hashbang cleanup on source files instead of acting on
  installed files in %%{buildroot}.
- Run spec-cleaner for minor formatting cleanups.
* Fri Jan 17 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update source URL.
* Fri Jan 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Make sure to provide/obsolete the python- subpkg to support
  migration
* Wed Jan  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.8:
  * Phase space biasing with Enhance_Observable re-enabled for
    unweighted events (!193, !209)
  * Significant reduction of negative weight fraction possible
    with NLO_CSS_PSMODE=1 option for leading-colour S-event
    showering (!200)
  * Improve safeguarding against large Sudakov reweighting factors
    (!212)
  * HepMC 3.1 interface added (!196)
  * Rivet 3.x interface added (!192)
  * Make OpenLoops library finding more robust, e.g. for LCG
    OpenLoops installation (!215)
  * Crash when soft spin correlations and neutral meson mixing
    were enabled (#53) -- thanks for the report from ATLAS
  * Widths updated in hard decay handler not used by ME generators
    (#182)
- Build against python3 instead of python(2).
- Build against HepMC (>=3) instead of HepMC2.
- Remove some hasbangs for non-exec files.
* Thu Oct 10 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Remove unused BuildRequires to openmpi
* Thu Sep  5 2019 Atri Bhattacharya <badshah400@gmail.com>
- Disable link-time-optimization to prevent build failures.
* Thu May 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Enable ufo-interface and package it as part of python-%%{name}
  package. Requires scons for building.
* Tue Feb  5 2019 Atri Bhattacharya <badshah400@gmail.com>
- Refresh source tarball: updated by upstream without version
  change or listing changes.
- Use %%%%license to install COPYING file.
- Minor specfile cleanups.
* Thu Jan 24 2019 badshah400@gmail.com
- Update to version 2.2.6:
  * Add initial-state p_z and inelasticity selectors for DIS (#80)
  * Improve the reweighting to include the local K=BBar/B factor
    in MEPS@NLO runs (#73)
  * Improve treatment of the shower reweighting scale cut-off, it
    is now applied also when reweighting AlphaS and the PDFs in
    the CKKW clustering sequence (also mentioned in #73)
  * Adapt status=4 convention in the short HepMC output (#79)
  * Compute approximate NLO EW corrections (and subleading orders)
    as on-the-fly alternative event weights (#41). See Example in
    Manual for details. Currently only works with a
    soon-to-be-released version of OpenLoops.
  * Add a filter between the perturbative and the non-perturbative
    event phase, which can be used to reject events with
    parton-level cuts (!94)
  * Bug fixes:
  - Fix NLO and Variable Selector routines (#70, #88)
  - Fix unweighting treatment for the LocalKFactor (and its
    on-the-fly variations) in negative events (#94)
  - Fix argument validation in
    GGH_KFactor_Setter::ClusterMassCorrectionFactor
  - Fix core scale setter for DIS when the incoming particles
    are ordered ep instead of pe and adapt it for ee->xy (where
    xy is not a quark pair) (!81)
  - Fix strong coupling reweighting in merging runs in cases
    where nothing was clustered (#66)
  - Fix beam remnants for DIS setups
  - Fix rejection of rare negative-energy configurations in the
    shower (#44)
  - Fix treatment of negative UserHook weights in HepMC
    interface (#100)
  - Fix a mapping in the OpenLoops parameter-setting interface
    (#87)
  - Fix HEFT Higgs production with COMIX (#114)
  - Fix compatibility issues with recent versions of Rivet
  - Fix error when compiling with MCFM support
  - Fix compilation on ARM/PowerPC architectures
  - Make environment importing when building scons scripts more
    bullet-proof
  - Fix compilation of the HZTool interface add-on
- Drop SHERPA-MC-fix_arm_build.patch: fixed upstream.
- Rebase SHERPA-MC-no-return-in-non-void-function.patch: partially
  upstreamed; fix new error introduced.
* Wed Apr 25 2018 guillaume.gardet@opensuse.org
- Update to 2.2.5:
  * Interface changes
  - Add preliminary support for HepMC3 (this interface is still
    being tested)
  * New features
  - Improve decay showering off top quarks
  - Improve single-top support and add examples and documentation
    for its production channels
  - Improve hadronisation and hadron decays for heavy flavour
    production
  - Introduce a user hook framework which allows users to easily
    implement
    event generation afterburners, see Examples/Userhook
  - Add settings to output ME-only on-the-fly variations (along with
    the full ones):
    HEPMC_INCLUDE_ME_ONLY_VARIATIONS=1 (HepMC interface)
  - New cut-off for parton-shower reweighting:
    CSS_REWEIGHT_SCALE_CUTOFF=<pt_min>, default: 5 GeV2
    this is more generally applicable than using a cut-off on the
  number of reweighted emissions
  - Improve support for on-the-fly variations of clustering steps
    (reweight each step locally instead of doing it globally)
  * Bugfixes
  - Fix issue with the overweight treatment for negative weights
  - Add missing shower weight in some event outputs, e.g. when using
    `OUTPUT HepMC...[]`
  - Fix issue with the overweight threshold for on-the-fly variations
  - Fix issue with non-trivial beam spectra handling
  - Fix possible issues with electron-"PDF" initialization
  - Fix issue with the ISR-channel threshold for leptonic collider
  - Fix X/Y functions in METOOLS (this is relevant for hadron decays)
  - Fix crash in decay-channel sorting
  - Fix crash when using EVENT_TYPE=HadronDecay
  - Fix issue with CSS strong coupling values when using non-trivial
    scale factors
  - Fix issue with QSF variations for real emission calculations with
    COMIX
  - Fix crash when doing on-the-fly variations and invalid dipole
    kinematics occur
  - Fix issue in the interplay of the flux and the BIWeight for 1 -> n
    processes
  - Fix issue when using vertices with a vanishing coupling
  - Fix rare "invalid amplitude" crashes
  - Fix issues when adding limits for the number of t-channel propagators
    in matrix elements
  - Fix issue with checking PDF availability when enforcing jet vetoes
  - Fix several compilation issues
- Add patch to fix ARM (and PPC) builds:
  * SHERPA-MC-fix_arm_build.patch
- Refresh partially upstreamed patch:
  * SHERPA-MC-no-return-in-non-void-function.patch
* Fri Sep  8 2017 badshah400@gmail.com
- Upstream released a new 2.2.4 tarball, so refresh sources.
* Sat Sep  2 2017 badshah400@gmail.com
- Update to version 2.2.4:
  * Interface Changes:
  - New default parameters for hadronisation model to improve
    heavy flavour production fractions and meson/baryon ratios.
  - Updates to Recola interface with some new parameter (names),
    please refer to the manual.
  - Make STRICT_METS the default scale setter to guarantee full
    scale setting accuracy for unweighted events.
  * New features
  - Availability of DIRE NLO parton shower (cf.
    arXiv:1705.00742). This is not (yet) the default shower, in
    particular not in NLO-merged configurations.
  - Higher numerical stability in parton shower kinematics
    (re)construction.
  - Add OVERWEIGHT_THRESHOLD allowing user to cap maximal weight
    during event generation (cf. manual).
  - Avoid spuriously large weights in NLO-merged samples due to
    instable PDF ratios.
  - Add interface for hadron-level selectors.
  - Add Max_N_TChannels option in Amegic.
  - Add possibility to identify partons which originate in the
    hard decay handler.
  - Restructure gzip support such that it can be switched off at
    runtime (USE_GZIP).
  - Enable on-the-fly reweighting for calculations with the
    Higgs (Interference) add-on for HIGGS_INTERERENCE_MODE 1, 2,
    3 or 4.
  * Bugfixes
  - Bugfix in NLO-matched parton shower emission for non-trivial
    colour structures like in V+2j@NLO. This fixes an eta
    asymmetry which was visible at the ~2%% level in such
    samples.
  - BSM models through UFO: fix running coupling behaviour and
    treatment of exotic color octets.
  - Bugfix in random generator for Poisson distributions with
    large mean values.
  - Bugfixes for segfaults and compiler warnings with gcc 7.1.
  - Bugfix for colour assignment in clustering for loop-induced
    merged processes.
  - Bugfix for decay showering in conjunction with NLO+PS
    matching.
- Change BuildRequires HepMC-devel to HepMC2-devel: not compatible
  with HepMC >= 3.0.
- Rename libSHERPA-MC-config to libSHERPA-MC0-config that follows
  the shared lib versioning. In addition the ld.so.conf.d file is
  also renamed to follow the shared lib version to make it
  possible to install multiple versions of the shared lib.
- Rebase SHERPA-MC-no-return-in-non-void-function.patch and add
  fixes for one more function showing the same issue in version
  2.2.4.
- GCC >= 6.0 required, build fails with older GCC for openSUSE <=
  1320.
* Fri Apr 28 2017 badshah400@gmail.com
- Update to version 2.2.3:
  * Support for the Recola one-loop generator for QCD corrections.
- Add SHERPA-MC-no-return-in-non-void-function.patch -- Fix a
  non-void (bool) function that was not returning any data to
  return "true".
* Mon Feb 13 2017 jengelh@inai.de
- Shared library package must only contain time-unique names;
  split off libSHERPA-MC-config.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 2.2.1:
  * Incoporation of approximate NLO EW corrections in MEPS@NLO
    simulation as described in arXiv:1511.08692
  * On-the-fly renormalisation and factorisation scale, PDF and
    alpha_s variations in the matrix elements for LO, LOPS, NLOPS,
    MEPS, MENLOPS and MEPS@NLO simulations as described in
    arXiv:1606.08753
- Changes from version 2.2.0: See
  https://sherpa.hepforge.org/trac/wiki/SherpaDownloads/Sherpa-2.2.0.
- Drop gcc6_char_cast.patch; incorporated upstream.
* Sun Jun 19 2016 jengelh@inai.de
- RPM group classification
- run install_info in preun to avoid errors of missing files
- Shared library subpackage is supposed to include the number
* Thu Jun 16 2016 normand@linux.vnet.ibm.com
-  new gcc6_char_cast.patch
* Mon Jun 23 2014 badshah400@gmail.com
- License tag in spefile corrected, should be GPL-2.0+ and
  GPL-3.0.
* Sun Jun 22 2014 badshah400@gmail.com
- Update to version 2.1.1 (Bug-fix release):
  + A bug related to MC@NLO has been fixed. This will affect the
    total cross section in heavy quark production at the level of
    few permille.
  + A bug related to parton showering in associated Higgs boson
    production has been fixed.
  + A problem related to SQLite database locking on IBM BG/Q
    systems has been solved.
  + A bug related to CS subtraction with Comix has been fixed.
    This will eliminate possible large weights in events
    containing extremely soft gluons.
  + A bug related to the QED corrections on the hard interaction
    accidentally being switched off has been fixed.
  + A bug related to the contents of the HepMC::PdfInfo? object
    in MC@NLO event generation has been fixed.
  + A bug in the underlying event simulation, presenting as a final
    state particle asymmetry, has been fixed. An update of the
    underlying event parameters was necessary, invalidating MPI
    grids generated with previous versions.
  + The Python interface to access Sherpa's matrix elements has
    been updated and supplemented with a C++ interface.
  + A bug in the CS subtraction in DRED has been fixed.
- Changes from version 2.1.0:
  + Introduced SQLite as the preferred storage manager
  + Spin correlated decay chains (Comix only), includes all 1->2
    and 1->3 decays allowed by the model, iterated to arbitrary
    decay chain length, all decay steps are dressed with QCD
    parton showers and QED corrections
  + MC@NLO H events with Comix, speeds up initialisation and
    runtime
- Packaging changes:
  + Disable rivet bindings until SHERPA-MC builds with latest
    Rivet >= 2.1.2
  + BuildRequires on sqlite3-devel introduced since version 2.1.0
  + Package new binaries init_nlo.sh, make2scons, plot_graphs.sh.
* Mon Dec 16 2013 badshah400@gmail.com
- Initial version.
